@@ -1,10 +1,9 @@
-from .__about__ import __version__
+from ._interpolation import interp_rolling_lagrange
 from ._krylov import bicg, bicgstab, cg, cgs, gmres, minres, qmr
 from ._nonlinear import bisect, regula_falsi
 from ._optimize import leastsq, minimize
 
 __all__ = [
-    "__version__",
     "bicg",
     "bicgstab",
     "cg",
@@ -18,4 +17,6 @@ __all__ = [
     #
     "bisect",
     "regula_falsi",
+    #
+    "interp_rolling_lagrange",
 ]
